# Prediction Challege

## Description 
The goal of the challenge is to predict the number of bicycle passing between 00:01 AM and 09:00 AM on Friday, April 2nd. To reach this gold we used the data from https://docs.google.com/spreadsheets/d/1ssxsl9AIobDofXFohvwxqCPF0tn6dgXpixhiDzus0iE/edit#gid=59478853. 

## How does it work
You have to execute the file **prediction.py**

## Visualisation
Clcik on the link, you also can execute **vis.py**
https://poncheele.github.io/Prediction_velo/